@@ -1,7 +1,8 @@
 use crate::engine_generator;
+use crate::out_model::class::Class;
 
 engine_generator!(
-    avg_die,
+    Class >> class >> avg_die,
     equipment_format,
     lowercase,
     markdown,
