@@ -1,6 +1,5 @@
 use crate::current_file::{dist, init};
-use crate::handlebars_engine::build;
-use crate::model::index::Index;
+use crate::in_model::index::Index;
 use crate::text_utils::path_normalize;
 use clap::{AppSettings, Clap};
 use once_cell::sync::Lazy;
@@ -14,7 +13,9 @@ use std::path::PathBuf;
 pub mod current_file;
 pub mod handlebars_definitions;
 pub mod handlebars_engine;
-pub mod model;
+pub mod into_model;
+pub mod in_model;
+pub mod out_model;
 pub mod text_utils;
 
 #[derive(Clap)]
@@ -56,12 +57,14 @@ fn main() {
     }
     init(path.parent().unwrap());
     let index = serde_yaml::from_reader::<_, Index>(fs::File::open(path.clone()).unwrap()).unwrap();
+    let index: crate::out_model::index::Index = index.into();
     let out = dist(opts.out.unwrap_or("dist".to_string()));
-    let _ = build(&index)
+    let _ = index
+        .build()
         .unwrap()
         .into_iter()
         .map(|(path, body)| {
-            let path = path_normalize(out.join(path));
+            let path = path_normalize(out.join(path.as_ref()));
             fs::create_dir_all(path.parent().unwrap()).unwrap();
             File::create(path).unwrap().write(body.as_bytes()).unwrap()
         })
